@@ -3,6 +3,7 @@ package HTML::FormFu::Constraint::MinMaxFields;
 use strict;
 use warnings;
 use base 'HTML::FormFu::Constraint::_others';
+use Class::C3;
 
 __PACKAGE__->mk_accessors(qw/ minimum maximum /);
 
@@ -10,7 +11,7 @@ __PACKAGE__->mk_accessors(qw/ minimum maximum /);
 *max = \&maximum;
 
 sub new {
-    my $self = shift->SUPER::new(@_);
+    my $self = shift->next::method(@_);
 
     $self->attach_errors_to_base(1);
 
@@ -41,24 +42,20 @@ sub process {
             eval { my @x = @$value };
             croak $@ if $@;
 
-            my @errors = eval {
-                $self->constrain_values( $value, $params );
-                };
+            my @errors = eval { $self->constrain_values( $value, $params ); };
             $count++ if !@errors && !$@;
         }
         else {
-            my $ok = eval {
-                $self->constrain_value($value);
-                };
+            my $ok = eval { $self->constrain_value($value); };
             $count++ if $ok && !$@;
         }
     }
 
-    return $self->mk_errors({
-        pass   => ( $count < $min || $count > $max ) ? 0 : 1,
-        failed => \@names,
-        names  => \@names,
-    });
+    return $self->mk_errors( {
+            pass => ( $count < $min || $count > $max ) ? 0 : 1,
+            failed => \@names,
+            names  => \@names,
+        } );
 }
 
 # return true if value is defined
