@@ -1,22 +1,34 @@
 package HTML::FormFu::Deflator;
-use Moose;
 
-with 'HTML::FormFu::Role::Populate';
+use strict;
+use warnings;
+use base 'Class::Accessor::Chained::Fast';
+use Class::C3;
 
-use HTML::FormFu::Attribute qw( mk_inherited_accessors );
-use HTML::FormFu::ObjectUtil qw( form name parent );
+use HTML::FormFu::ObjectUtil qw( populate form name );
 use Carp qw( croak );
 
-has type => ( is => 'rw', traits  => ['Chained'] );
+__PACKAGE__->mk_accessors(qw/ parent type /);
 
-__PACKAGE__->mk_inherited_accessors(qw( locale ));
+sub new {
+    my $class = shift;
+
+    my %attrs;
+    eval { %attrs = %{ $_[0] } if @_ };
+    croak "attributes argument must be a hashref" if $@;
+
+    my $self = bless {}, $class;
+
+    $self->populate( \%attrs );
+
+    return $self;
+}
 
-sub BUILD {}
 sub process {
     my ( $self, $values ) = @_;
 
     if ( ref $values eq 'ARRAY' ) {
-        return [ map { $self->deflator($_) } @$values ];
+        return [ map { $self->deflator($_); } @$values ];
     }
     else {
         return $self->deflator($values);
@@ -31,15 +43,13 @@ sub clone {
     return bless \%new, ref $self;
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
 
 =head1 NAME
 
-HTML::FormFu::Deflator - Deflator Base Class
+HTML::FormFu::Filter - Deflator Base Class
 
 =head1 SYNOPSIS
 
@@ -63,22 +73,6 @@ Contains names of params to deflator.
 
 Arguments: $form_result, \%params
 
-=head1 CORE DEFLATORS
-
-=over
-
-=item L<HTML::FormFu::Deflator::CompoundDateTime>
-
-=item L<HTML::FormFu::Deflator::CompoundSplit>
-
-=item L<HTML::FormFu::Deflator::FormatNumber>
-
-=item L<HTML::FormFu::Deflator::PathClassFile>
-
-=item L<HTML::FormFu::Deflator::Strftime>
-
-=back
-
 =head1 AUTHOR
 
 Carl Franks, C<cfranks@cpan.org>
@@ -87,5 +81,3 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
-
-=cut
